AutoSizerPlatformDispatcher class

Implemented types

Properties

accessibilityFeatures AccessibilityFeatures
Additional accessibility features that may be enabled by the platform.
no setteroverride
alwaysUse24HourFormat bool
The setting indicating whether time should always be shown in the 24-hour format.
no setteroverride
brieflyShowPassword bool
Whether briefly displaying the characters as you type in obscured text fields is enabled in system settings.
no setteroverride
defaultRouteName String
The route or path that the embedder requested when the application was launched.
no setteroverride
displays Iterable<AutoSizerDisplay>
The current list of displays.
no setteroverride
engineId int?
Opaque engine identifier for the engine running current isolate. Can be used in native code to retrieve the engine instance. The identifier is valid while the isolate is running.
no setteroverride
frameData FrameData
The FrameData object for the current frame.
no setteroverride
hashCode int
The hash code for this object.
no setterinherited
implicitView FlutterView?
The FlutterView provided by the engine if the platform is unable to create windows, or, for backwards compatibility.
no setteroverride
initialLifecycleState String
The lifecycle state immediately after dart isolate initialization.
no setteroverride
letterSpacingOverride double?
The system-suggested amount of additional space (in logical pixels) to add between each letter.
no setterinherited
lineHeightScaleFactorOverride double?
The system-suggested height of the text, as a multiple of the font size.
no setterinherited
locale Locale
The system-reported default locale of the device.
no setteroverride
locales List<Locale>
The full system-reported supported locales of the device.
no setteroverride
nativeSpellCheckServiceDefined bool
Whether the spell check service is supported on the current platform.
no setteroverride
onAccessibilityFeaturesChanged VoidCallback?
A callback that is invoked when the value of accessibilityFeatures changes.
getter/setter pairoverride
onBeginFrame FrameCallback?
A callback invoked when any view begins a frame.
getter/setter pairoverride
onDrawFrame VoidCallback?
A callback that is invoked for each frame after onBeginFrame has completed and after the microtask queue has been drained.
getter/setter pairoverride
onError ErrorCallback?
A callback that is invoked when an unhandled error occurs in the root isolate.
getter/setter pairoverride
onFrameDataChanged VoidCallback?
A callback that is invoked when the window updates the FrameData.
getter/setter pairoverride
onKeyData KeyDataCallback?
A callback that is invoked when key data is available.
getter/setter pairoverride
onLocaleChanged VoidCallback?
A callback that is invoked whenever locale changes value.
getter/setter pairoverride
onMetricsChanged VoidCallback?
A callback that is invoked whenever the ViewConfiguration of any of the views changes.
getter/setter pairoverride
onPlatformBrightnessChanged VoidCallback?
A callback that is invoked whenever platformBrightness changes value.
getter/setter pairoverride
onPlatformConfigurationChanged VoidCallback?
Called when the platform configuration changes.
getter/setter pairoverride
onPlatformMessage PlatformMessageCallback?
Deprecated. Migrate to ChannelBuffers.setListener instead.
getter/setter pairoverride
onPointerDataPacket PointerDataPacketCallback?
A callback that is invoked when pointer data is available.
getter/setter pairoverride
onReportTimings TimingsCallback?
A callback that is invoked to report the FrameTiming of recently rasterized frames.
getter/setter pairoverride
onSemanticsActionEvent SemanticsActionEventCallback?
A callback that is invoked whenever the user requests an action to be performed on a semantics node.
getter/setter pairoverride
onSemanticsEnabledChanged VoidCallback?
A callback that is invoked when the value of semanticsEnabled changes.
getter/setter pairoverride
onSystemFontFamilyChanged VoidCallback?
A callback that is invoked whenever systemFontFamily changes value.
getter/setter pairoverride
onTextScaleFactorChanged VoidCallback?
A callback that is invoked whenever textScaleFactor changes value.
getter/setter pairoverride
onViewFocusChange ViewFocusChangeCallback?
A callback invoked immediately after the focus is transitioned across FlutterViews.
getter/setter pairoverride
paragraphSpacingOverride double?
The system-suggested amount of additional space (in logical pixels) to add following each paragraph in text.
no setterinherited
platformBrightness Brightness
The setting indicating the current brightness mode of the host platform. If the platform has no preference, platformBrightness defaults to Brightness.light.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
semanticsEnabled bool
Whether the user has requested that updateSemantics be called when the semantic contents of a view changes.
no setteroverride
supportsShowingSystemContextMenu bool
Whether showing system context menu is supported on the current platform.
no setteroverride
systemFontFamily String?
The setting indicating the current system font of the host platform.
no setteroverride
textScaleFactor double
The system-reported text scale.
no setteroverride
views Iterable<FlutterView>
The current list of views, including top level platform windows used by the application.
no setteroverride
wordSpacingOverride double?
The system-suggested amount of additional space (in logical pixels) to add between each sequence of white-space (i.e. between each word).
no setterinherited

Methods

computePlatformResolvedLocale(List<Locale> supportedLocales) Locale?
Performs the platform-native locale resolution.
override
getPersistentIsolateData() ByteData?
The embedder can specify data that the isolate can request synchronously on launch. This accessor fetches that data.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
registerBackgroundIsolate(RootIsolateToken token) → void
Registers the current isolate with the isolate identified with by the token. This is required if platform channels are to be used on a background isolate.
override
requestDartPerformanceMode(DartPerformanceMode mode) → void
Requests the Dart VM to adjusts the GC heuristics based on the requested performance_mode.
override
requestViewFocusChange({required int viewId, required ViewFocusState state, required ViewFocusDirection direction}) → void
Requests a focus change of the FlutterView with ID viewId.
override
scaleFontSize(double unscaledFontSize) double
Computes the scaled font size from the given unscaledFontSize, according to the user's platform preferences.
override
scheduleFrame() → void
Requests that, at the next appropriate opportunity, the onBeginFrame and onDrawFrame callbacks be invoked.
override
scheduleWarmUpFrame({required VoidCallback beginFrame, required VoidCallback drawFrame}) → void
Schedule a frame to run as soon as possible, rather than waiting for the engine to request a frame in response to a system "Vsync" signal.
override
sendPlatformMessage(String name, ByteData? data, PlatformMessageResponseCallback? callback) → void
Sends a message to a platform-specific plugin.
override
sendPortPlatformMessage(String name, ByteData? data, int identifier, SendPort port) → void
Sends a message to a platform-specific plugin via a SendPort.
override
setApplicationLocale(Locale locale) → void
Sets the locale for the application in engine.
inherited
setIsolateDebugName(String name) → void
Set the debug name associated with this platform dispatcher's root isolate.
override
setSemanticsTreeEnabled(bool enabled) → void
Informs the engine whether the framework is generating a semantics tree.
inherited
toString() String
A string representation of this object.
inherited
updateSemantics(SemanticsUpdate update) → void
Change the retained semantics data about this platform dispatcher.
override
view({required int id}) FlutterView?
Returns the FlutterView with the provided ID if one exists, or null otherwise.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

instance AutoSizerPlatformDispatcher
no setter