Opaque engine identifier for the engine running current isolate. Can be used
in native code to retrieve the engine instance.
The identifier is valid while the isolate is running.
Implementation
@override
int? get engineId => _platformDispatcher.engineId;