nativeSpellCheckServiceDefined property
Whether the spell check service is supported on the current platform.
This option is used by EditableTextState to define its SpellCheckConfiguration when a default spell check service is requested.
Implementation
@override
bool get nativeSpellCheckServiceDefined => _platformDispatcher.nativeSpellCheckServiceDefined;