AutoSizerDisplay class

Implemented types
Implementers

Constructors

AutoSizerDisplay(AutoSizerPlatformDispatcher platformDispatcher, Display display)

Properties

devicePixelRatio double
The device pixel ratio of this display.
no setteroverride
hashCode int
The hash code for this object.
no setterinherited
id int
A unique identifier for this display.
no setteroverride
refreshRate double
The refresh rate in FPS of this display.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
size Size
The physical size of this display.
no setteroverride

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited