devicePixelRatio property
The device pixel ratio of this display.
This value is the same as the value of FlutterView.devicePixelRatio for all view objects attached to this display.
Implementation
@override
double get devicePixelRatio => AutoSizer.instance.devicePixelRatio;