A unique identifier for this display.
This identifier is unique among a list of displays the Flutter framework is aware of, and is not derived from any platform specific identifiers for displays.
@override int get id => _display.id;