AutoSizerView class

Implemented types

Constructors

AutoSizerView({required FlutterView view, required AutoSizerPlatformDispatcher platformDispatcher, required AutoSizerDisplay display})

Properties

devicePixelRatio double
The number of device pixels for each logical pixel for the screen this view is displayed on.
no setteroverride
display AutoSizerDisplay
The Display this view is drawn in.
no setteroverride
displayFeatures List<DisplayFeature>
Areas of the display that are obstructed by hardware features.
no setteroverride
gestureSettings GestureSettings
Additional configuration for touch gestures performed on this view.
getter/setter pairoverride-getter
hashCode int
The hash code for this object.
no setterinherited
padding AutoSizerViewPadding
The number of physical pixels on each side of the display rectangle into which the view can render, but which may be partially obscured by system UI (such as the system notification area), or physical intrusions in the display (e.g. overscan regions on television screens or phone sensor housings).
no setteroverride
physicalConstraints ViewConstraints
The sizing constraints in physical pixels for this view.
no setteroverride
physicalGeometry Rect
no getter
physicalSize Size
The current dimensions of the rectangle as last reported by the platform into which scenes rendered in this view are drawn.
getter/setter pairoverride-getter
platformDispatcher AutoSizerPlatformDispatcher
The platform dispatcher that this view is registered with, and gets its information from.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
systemGestureInsets AutoSizerViewPadding
The number of physical pixels on each side of the display rectangle into which the view can render, but where the operating system will consume input gestures for the sake of system navigation.
getter/setter pairoverride-getter
viewId int
The opaque ID for this view.
no setteroverride
viewInsets AutoSizerViewPadding
The number of physical pixels on each side of the display rectangle into which the view can render, but over which the operating system will likely place system UI, such as the keyboard, that fully obscures any content.
getter/setter pairoverride-getter
viewPadding AutoSizerViewPadding
The number of physical pixels on each side of the display rectangle into which the view can render, but which may be partially obscured by system UI (such as the system notification area), or physical intrusions in the display (e.g. overscan regions on television screens or phone sensor housings).
getter/setter pairoverride-getter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
override
render(Scene scene, {Size? size}) → void
Updates the view's rendering on the GPU with the newly provided Scene.
override
toString() String
A string representation of this object.
inherited
updateSemantics(SemanticsUpdate update) → void
Change the retained semantics data about this FlutterView.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited