gestureSettings property

  1. @override
GestureSettings get gestureSettings
override

Additional configuration for touch gestures performed on this view.

For example, the touch slop defined in physical pixels may be provided by the gesture settings and should be preferred over the framework touch slop constant.

Implementation

@override
GestureSettings get gestureSettings => _gestureSettings ?? _view.gestureSettings;
set gestureSettings (GestureSettings value)

Implementation

set gestureSettings(GestureSettings value) {
  _gestureSettings = value;
  platformDispatcher.onMetricsChanged?.call();
}