platformDispatcher property
The platform dispatcher that this view is registered with, and gets its information from.
Implementation
@override
AutoSizerPlatformDispatcher get platformDispatcher => _platformDispatcher;
The platform dispatcher that this view is registered with, and gets its information from.
@override
AutoSizerPlatformDispatcher get platformDispatcher => _platformDispatcher;