AutoSizer class
Properties
- designSize → Size
-
no setter
- devicePixelRatio → double
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
init(
Size designSize, {SizerMode mode = SizerMode.portrait}) → void -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
onMetricsChanged(
) → void - 当屏幕发生变化时,如屏幕旋转
-
onViewFocusChange(
) → void - 当焦点发生变化时
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited